summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--oslo_db/sqlalchemy/enginefacade.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/oslo_db/sqlalchemy/enginefacade.py b/oslo_db/sqlalchemy/enginefacade.py
index 1617ebb..7006a2d 100644
--- a/oslo_db/sqlalchemy/enginefacade.py
+++ b/oslo_db/sqlalchemy/enginefacade.py
@@ -164,15 +164,15 @@ class _TransactionFactory(object):
'on_engine_create': [],
}
# other options that are defined in oslo.db.options.database_opts
# but do not apply to the standard enginefacade arguments
# (most seem to apply to api.DBAPI).
self._ignored_cfg = dict(
(k, _Default(None)) for k in [
'db_max_retries', 'db_inc_retry_interval',
'use_db_reconnect',
'db_retry_interval', 'min_pool_size',
- 'db_max_retry_interval', 'backend'])
+ 'db_max_retry_interval', 'backend', 'use_tpool'])
self._started = False
self._legacy_facade = None
@@ -164,15 +164,15 @@ class _TransactionFactory(object):
'on_engine_create': [],
}
- # other options that are defined in oslo.db.options.database_opts
- # but do not apply to the standard enginefacade arguments
- # (most seem to apply to api.DBAPI).
+ # other options that are defined in oslo_db.options.database_opts
+ # or oslo_db.concurrency.tpool_opts but do not apply to the standard
+ # enginefacade arguments (most seem to apply to api.DBAPI).
self._ignored_cfg = dict(
(k, _Default(None)) for k in [